@@ -35,28 +35,6 @@ pub struct Table {
 }
 
 impl Table {
-    pub fn dump(&self, db: &DB) {
-        println!("Dumping Table {}", self.info.name.str());
-        let mut row = self.row();
-        for (pp, off) in self.scan(db) {
-            let p = pp.borrow();
-            let data = &p.data[off..];
-            row.load(db, data);
-            println!("row id={} values={:?}", row.id, row.values);
-        }
-    }
-    pub fn dump_index(self: &TablePtr, db: &DB, ix: usize) {
-        println!("Dumping Index {} ix={}", self.info.name.str(), ix);
-        let mut row = self.row();
-        let keys = Vec::new();
-        for (pp, off) in self.scan_keys(db, keys, ix) {
-            let p = pp.borrow();
-            let data = &p.data[off..];
-            row.load(db, data);
-            println!("row id={} values={:?}", row.id, row.values);
-        }
-    }
-
     /// Construct a table with specified info.
     pub fn new(id: i64, root_page: u64, id_gen: i64, info: Rc<ColInfo>) -> TablePtr {
         let rec_size = info.total;
@@ -167,7 +145,7 @@ impl Table {
                 }
             }
         }
-        // println!("No index found for table {}", self.info.name.to_str());
+        println!("No index found for table {}", self.info.name.str());
         (Some(c_bool(b, we)), None)
     }
 
@@ -414,6 +392,31 @@ impl ColInfo {
         false
     }
 
+    pub fn add_altered(&mut self, ci: &ColInfo, cnum: usize, actions: &[AlterCol]) -> bool {
+        let cname = &ci.colnames[cnum];
+        let mut typ = ci.typ[cnum];
+        for act in actions {
+            match act {
+                AlterCol::Drop(name) => {
+                    if name == cname {
+                        return false;
+                    }
+                }
+                AlterCol::Modify(name, dt) => {
+                    if name == cname {
+                        if data_kind(typ) != data_kind(*dt) {
+                            panic!("Cannot change column data kind");
+                        }
+                        typ = *dt;
+                    }
+                }
+                _ => {}
+            }
+        }
+        self.add(cname.clone(), typ);
+        true
+    }
+
     /// Get a column number from a column name.
     /// usize::MAX is returned for "Id".
     pub fn get(&self, name: &str) -> Option<&usize> {
